.. -*- coding: utf-8 -*-

.. _`PEG_1chain-dataset`:

PEG polymer dataset
===================

MD trajectory showing the self-assembly of an amphiphilic molecule.

The topology is contained in the PRMTOP file (AMBER format). The
trajectory is contained in the NETCDF (.nc) file (AMBER format).


Notes
-----

Data set characteristics:

 :size: 10 MB
 :number of trajectories: 1
 :creator: Micaela Matta
 :URL:  `<https://figshare.com/articles/PEG_single_chain/7325774>`_
 :license: `CC-BY 4.0 <https://creativecommons.org/licenses/by/4.0/legalcode>`_
